// Copyright (c) 2014 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef THIRD_PARTY_BLINK_RENDERER_CORE_CSS_CSS_PROPERTY_NAMES_H_
#define THIRD_PARTY_BLINK_RENDERER_CORE_CSS_CSS_PROPERTY_NAMES_H_

#include <stddef.h>
#include "third_party/blink/public/mojom/use_counter/css_property_id.mojom-blink.h"
#include "third_party/blink/renderer/core/core_export.h"
#include "third_party/blink/renderer/platform/wtf/allocator/allocator.h"
#include "third_party/blink/renderer/platform/wtf/assertions.h"

namespace WTF {
class AtomicString;
class String;
}

namespace blink {

enum class CSSPropertyID {
    kInvalid = 0,
    kVariable = 1,
    kAnimationDelay = 2,
    kAnimationDirection = 3,
    kAnimationDuration = 4,
    kAnimationFillMode = 5,
    kAnimationIterationCount = 6,
    kAnimationName = 7,
    kAnimationPlayState = 8,
    kAnimationTimingFunction = 9,
    kTransitionDelay = 10,
    kTransitionDuration = 11,
    kTransitionProperty = 12,
    kTransitionTimingFunction = 13,
    kColor = 14,
    kColorScheme = 15,
    kDirection = 16,
    kFontFamily = 17,
    kFontFeatureSettings = 18,
    kFontKerning = 19,
    kFontSize = 20,
    kFontSizeAdjust = 21,
    kFontStretch = 22,
    kFontStyle = 23,
    kFontVariantCaps = 24,
    kFontVariantEastAsian = 25,
    kFontVariantLigatures = 26,
    kFontVariantNumeric = 27,
    kFontVariationSettings = 28,
    kFontWeight = 29,
    kForcedColorAdjust = 30,
    kInternalEffectiveZoom = 31,
    kInternalVisitedColor = 32,
    kTextOrientation = 33,
    kTextRendering = 34,
    kWebkitFontSmoothing = 35,
    kWebkitLocale = 36,
    kWebkitTextOrientation = 37,
    kWebkitWritingMode = 38,
    kWritingMode = 39,
    kZoom = 40,
    kAlignContent = 41,
    kAlignItems = 42,
    kAlignSelf = 43,
    kAlignmentBaseline = 44,
    kAll = 45,
    kBackdropFilter = 46,
    kBackfaceVisibility = 47,
    kBackgroundAttachment = 48,
    kBackgroundBlendMode = 49,
    kBackgroundClip = 50,
    kBackgroundColor = 51,
    kBackgroundImage = 52,
    kBackgroundOrigin = 53,
    kBackgroundPositionX = 54,
    kBackgroundPositionY = 55,
    kBackgroundRepeatX = 56,
    kBackgroundRepeatY = 57,
    kBackgroundSize = 58,
    kBaselineShift = 59,
    kBlockSize = 60,
    kBorderBlockEndColor = 61,
    kBorderBlockEndStyle = 62,
    kBorderBlockEndWidth = 63,
    kBorderBlockStartColor = 64,
    kBorderBlockStartStyle = 65,
    kBorderBlockStartWidth = 66,
    kBorderBottomColor = 67,
    kBorderBottomLeftRadius = 68,
    kBorderBottomRightRadius = 69,
    kBorderBottomStyle = 70,
    kBorderBottomWidth = 71,
    kBorderCollapse = 72,
    kBorderImageOutset = 73,
    kBorderImageRepeat = 74,
    kBorderImageSlice = 75,
    kBorderImageSource = 76,
    kBorderImageWidth = 77,
    kBorderInlineEndColor = 78,
    kBorderInlineEndStyle = 79,
    kBorderInlineEndWidth = 80,
    kBorderInlineStartColor = 81,
    kBorderInlineStartStyle = 82,
    kBorderInlineStartWidth = 83,
    kBorderLeftColor = 84,
    kBorderLeftStyle = 85,
    kBorderLeftWidth = 86,
    kBorderRightColor = 87,
    kBorderRightStyle = 88,
    kBorderRightWidth = 89,
    kBorderTopColor = 90,
    kBorderTopLeftRadius = 91,
    kBorderTopRightRadius = 92,
    kBorderTopStyle = 93,
    kBorderTopWidth = 94,
    kBottom = 95,
    kBoxShadow = 96,
    kBoxSizing = 97,
    kBreakAfter = 98,
    kBreakBefore = 99,
    kBreakInside = 100,
    kBufferedRendering = 101,
    kCaptionSide = 102,
    kCaretColor = 103,
    kClear = 104,
    kClip = 105,
    kClipPath = 106,
    kClipRule = 107,
    kColorInterpolation = 108,
    kColorInterpolationFilters = 109,
    kColorRendering = 110,
    kColumnCount = 111,
    kColumnFill = 112,
    kColumnGap = 113,
    kColumnRuleColor = 114,
    kColumnRuleStyle = 115,
    kColumnRuleWidth = 116,
    kColumnSpan = 117,
    kColumnWidth = 118,
    kContain = 119,
    kContent = 120,
    kContentSize = 121,
    kCounterIncrement = 122,
    kCounterReset = 123,
    kCursor = 124,
    kCx = 125,
    kCy = 126,
    kD = 127,
    kDisplay = 128,
    kDominantBaseline = 129,
    kEmptyCells = 130,
    kFill = 131,
    kFillOpacity = 132,
    kFillRule = 133,
    kFilter = 134,
    kFlexBasis = 135,
    kFlexDirection = 136,
    kFlexGrow = 137,
    kFlexShrink = 138,
    kFlexWrap = 139,
    kFloat = 140,
    kFloodColor = 141,
    kFloodOpacity = 142,
    kFontDisplay = 143,
    kGridAutoColumns = 144,
    kGridAutoFlow = 145,
    kGridAutoRows = 146,
    kGridColumnEnd = 147,
    kGridColumnStart = 148,
    kGridRowEnd = 149,
    kGridRowStart = 150,
    kGridTemplateAreas = 151,
    kGridTemplateColumns = 152,
    kGridTemplateRows = 153,
    kHeight = 154,
    kHyphens = 155,
    kImageOrientation = 156,
    kImageRendering = 157,
    kInherits = 158,
    kInitialValue = 159,
    kInlineSize = 160,
    kInsetBlockEnd = 161,
    kInsetBlockStart = 162,
    kInsetInlineEnd = 163,
    kInsetInlineStart = 164,
    kInternalVisitedBackgroundColor = 165,
    kInternalVisitedBorderBlockEndColor = 166,
    kInternalVisitedBorderBlockStartColor = 167,
    kInternalVisitedBorderBottomColor = 168,
    kInternalVisitedBorderInlineEndColor = 169,
    kInternalVisitedBorderInlineStartColor = 170,
    kInternalVisitedBorderLeftColor = 171,
    kInternalVisitedBorderRightColor = 172,
    kInternalVisitedBorderTopColor = 173,
    kInternalVisitedCaretColor = 174,
    kInternalVisitedColumnRuleColor = 175,
    kInternalVisitedFill = 176,
    kInternalVisitedOutlineColor = 177,
    kInternalVisitedStroke = 178,
    kInternalVisitedTextDecorationColor = 179,
    kInternalVisitedTextEmphasisColor = 180,
    kInternalVisitedTextFillColor = 181,
    kInternalVisitedTextStrokeColor = 182,
    kIsolation = 183,
    kJustifyContent = 184,
    kJustifyItems = 185,
    kJustifySelf = 186,
    kLeft = 187,
    kLetterSpacing = 188,
    kLightingColor = 189,
    kLineBreak = 190,
    kLineHeight = 191,
    kLineHeightStep = 192,
    kListStyleImage = 193,
    kListStylePosition = 194,
    kListStyleType = 195,
    kMarginBlockEnd = 196,
    kMarginBlockStart = 197,
    kMarginBottom = 198,
    kMarginInlineEnd = 199,
    kMarginInlineStart = 200,
    kMarginLeft = 201,
    kMarginRight = 202,
    kMarginTop = 203,
    kMarkerEnd = 204,
    kMarkerMid = 205,
    kMarkerStart = 206,
    kMask = 207,
    kMaskSourceType = 208,
    kMaskType = 209,
    kMaxBlockSize = 210,
    kMaxHeight = 211,
    kMaxInlineSize = 212,
    kMaxWidth = 213,
    kMaxZoom = 214,
    kMinBlockSize = 215,
    kMinHeight = 216,
    kMinInlineSize = 217,
    kMinWidth = 218,
    kMinZoom = 219,
    kMixBlendMode = 220,
    kObjectFit = 221,
    kObjectPosition = 222,
    kOffsetAnchor = 223,
    kOffsetDistance = 224,
    kOffsetPath = 225,
    kOffsetPosition = 226,
    kOffsetRotate = 227,
    kOpacity = 228,
    kOrder = 229,
    kOrientation = 230,
    kOrphans = 231,
    kOutlineColor = 232,
    kOutlineOffset = 233,
    kOutlineStyle = 234,
    kOutlineWidth = 235,
    kOverflowAnchor = 236,
    kOverflowBlock = 237,
    kOverflowInline = 238,
    kOverflowWrap = 239,
    kOverflowX = 240,
    kOverflowY = 241,
    kOverscrollBehaviorBlock = 242,
    kOverscrollBehaviorInline = 243,
    kOverscrollBehaviorX = 244,
    kOverscrollBehaviorY = 245,
    kPaddingBlockEnd = 246,
    kPaddingBlockStart = 247,
    kPaddingBottom = 248,
    kPaddingInlineEnd = 249,
    kPaddingInlineStart = 250,
    kPaddingLeft = 251,
    kPaddingRight = 252,
    kPaddingTop = 253,
    kPage = 254,
    kPaintOrder = 255,
    kPerspective = 256,
    kPerspectiveOrigin = 257,
    kPointerEvents = 258,
    kPosition = 259,
    kQuotes = 260,
    kR = 261,
    kResize = 262,
    kRight = 263,
    kRotate = 264,
    kRowGap = 265,
    kRx = 266,
    kRy = 267,
    kScale = 268,
    kScrollBehavior = 269,
    kScrollCustomization = 270,
    kScrollMarginBlockEnd = 271,
    kScrollMarginBlockStart = 272,
    kScrollMarginBottom = 273,
    kScrollMarginInlineEnd = 274,
    kScrollMarginInlineStart = 275,
    kScrollMarginLeft = 276,
    kScrollMarginRight = 277,
    kScrollMarginTop = 278,
    kScrollPaddingBlockEnd = 279,
    kScrollPaddingBlockStart = 280,
    kScrollPaddingBottom = 281,
    kScrollPaddingInlineEnd = 282,
    kScrollPaddingInlineStart = 283,
    kScrollPaddingLeft = 284,
    kScrollPaddingRight = 285,
    kScrollPaddingTop = 286,
    kScrollSnapAlign = 287,
    kScrollSnapStop = 288,
    kScrollSnapType = 289,
    kShapeImageThreshold = 290,
    kShapeMargin = 291,
    kShapeOutside = 292,
    kShapeRendering = 293,
    kSize = 294,
    kSpeak = 295,
    kSrc = 296,
    kStopColor = 297,
    kStopOpacity = 298,
    kStroke = 299,
    kStrokeDasharray = 300,
    kStrokeDashoffset = 301,
    kStrokeLinecap = 302,
    kStrokeLinejoin = 303,
    kStrokeMiterlimit = 304,
    kStrokeOpacity = 305,
    kStrokeWidth = 306,
    kSyntax = 307,
    kTabSize = 308,
    kTableLayout = 309,
    kTextAlign = 310,
    kTextAlignLast = 311,
    kTextAnchor = 312,
    kTextCombineUpright = 313,
    kTextDecorationColor = 314,
    kTextDecorationLine = 315,
    kTextDecorationSkipInk = 316,
    kTextDecorationStyle = 317,
    kTextIndent = 318,
    kTextJustify = 319,
    kTextOverflow = 320,
    kTextShadow = 321,
    kTextSizeAdjust = 322,
    kTextTransform = 323,
    kTextUnderlinePosition = 324,
    kTop = 325,
    kTouchAction = 326,
    kTransform = 327,
    kTransformBox = 328,
    kTransformOrigin = 329,
    kTransformStyle = 330,
    kTranslate = 331,
    kUnicodeBidi = 332,
    kUnicodeRange = 333,
    kUserSelect = 334,
    kUserZoom = 335,
    kVectorEffect = 336,
    kVerticalAlign = 337,
    kViewportFit = 338,
    kVisibility = 339,
    kWebkitAppRegion = 340,
    kWebkitAppearance = 341,
    kWebkitBorderHorizontalSpacing = 342,
    kWebkitBorderImage = 343,
    kWebkitBorderVerticalSpacing = 344,
    kWebkitBoxAlign = 345,
    kWebkitBoxDecorationBreak = 346,
    kWebkitBoxDirection = 347,
    kWebkitBoxFlex = 348,
    kWebkitBoxOrdinalGroup = 349,
    kWebkitBoxOrient = 350,
    kWebkitBoxPack = 351,
    kWebkitBoxReflect = 352,
    kWebkitFontSizeDelta = 353,
    kWebkitHighlight = 354,
    kWebkitHyphenateCharacter = 355,
    kWebkitLineBreak = 356,
    kWebkitLineClamp = 357,
    kWebkitMarginAfterCollapse = 358,
    kWebkitMarginBeforeCollapse = 359,
    kWebkitMarginBottomCollapse = 360,
    kWebkitMarginTopCollapse = 361,
    kWebkitMaskBoxImageOutset = 362,
    kWebkitMaskBoxImageRepeat = 363,
    kWebkitMaskBoxImageSlice = 364,
    kWebkitMaskBoxImageSource = 365,
    kWebkitMaskBoxImageWidth = 366,
    kWebkitMaskClip = 367,
    kWebkitMaskComposite = 368,
    kWebkitMaskImage = 369,
    kWebkitMaskOrigin = 370,
    kWebkitMaskPositionX = 371,
    kWebkitMaskPositionY = 372,
    kWebkitMaskRepeatX = 373,
    kWebkitMaskRepeatY = 374,
    kWebkitMaskSize = 375,
    kWebkitPerspectiveOriginX = 376,
    kWebkitPerspectiveOriginY = 377,
    kWebkitPrintColorAdjust = 378,
    kWebkitRtlOrdering = 379,
    kWebkitRubyPosition = 380,
    kWebkitTapHighlightColor = 381,
    kWebkitTextCombine = 382,
    kWebkitTextDecorationsInEffect = 383,
    kWebkitTextEmphasisColor = 384,
    kWebkitTextEmphasisPosition = 385,
    kWebkitTextEmphasisStyle = 386,
    kWebkitTextFillColor = 387,
    kWebkitTextSecurity = 388,
    kWebkitTextStrokeColor = 389,
    kWebkitTextStrokeWidth = 390,
    kWebkitTransformOriginX = 391,
    kWebkitTransformOriginY = 392,
    kWebkitTransformOriginZ = 393,
    kWebkitUserDrag = 394,
    kWebkitUserModify = 395,
    kWhiteSpace = 396,
    kWidows = 397,
    kWidth = 398,
    kWillChange = 399,
    kWordBreak = 400,
    kWordSpacing = 401,
    kX = 402,
    kY = 403,
    kZIndex = 404,
    kAnimation = 405,
    kBackground = 406,
    kBackgroundPosition = 407,
    kBackgroundRepeat = 408,
    kBorder = 409,
    kBorderBlock = 410,
    kBorderBlockColor = 411,
    kBorderBlockEnd = 412,
    kBorderBlockStart = 413,
    kBorderBlockStyle = 414,
    kBorderBlockWidth = 415,
    kBorderBottom = 416,
    kBorderColor = 417,
    kBorderImage = 418,
    kBorderInline = 419,
    kBorderInlineColor = 420,
    kBorderInlineEnd = 421,
    kBorderInlineStart = 422,
    kBorderInlineStyle = 423,
    kBorderInlineWidth = 424,
    kBorderLeft = 425,
    kBorderRadius = 426,
    kBorderRight = 427,
    kBorderSpacing = 428,
    kBorderStyle = 429,
    kBorderTop = 430,
    kBorderWidth = 431,
    kColumnRule = 432,
    kColumns = 433,
    kFlex = 434,
    kFlexFlow = 435,
    kFont = 436,
    kFontVariant = 437,
    kGap = 438,
    kGrid = 439,
    kGridArea = 440,
    kGridColumn = 441,
    kGridColumnGap = 442,
    kGridGap = 443,
    kGridRow = 444,
    kGridRowGap = 445,
    kGridTemplate = 446,
    kInset = 447,
    kInsetBlock = 448,
    kInsetInline = 449,
    kListStyle = 450,
    kMargin = 451,
    kMarginBlock = 452,
    kMarginInline = 453,
    kMarker = 454,
    kOffset = 455,
    kOutline = 456,
    kOverflow = 457,
    kOverscrollBehavior = 458,
    kPadding = 459,
    kPaddingBlock = 460,
    kPaddingInline = 461,
    kPageBreakAfter = 462,
    kPageBreakBefore = 463,
    kPageBreakInside = 464,
    kPlaceContent = 465,
    kPlaceItems = 466,
    kPlaceSelf = 467,
    kScrollMargin = 468,
    kScrollMarginBlock = 469,
    kScrollMarginInline = 470,
    kScrollPadding = 471,
    kScrollPaddingBlock = 472,
    kScrollPaddingInline = 473,
    kTextDecoration = 474,
    kTransition = 475,
    kWebkitColumnBreakAfter = 476,
    kWebkitColumnBreakBefore = 477,
    kWebkitColumnBreakInside = 478,
    kWebkitMarginCollapse = 479,
    kWebkitMask = 480,
    kWebkitMaskBoxImage = 481,
    kWebkitMaskPosition = 482,
    kWebkitMaskRepeat = 483,
    kWebkitTextEmphasis = 484,
    kWebkitTextStroke = 485,
    kAliasWebkitBorderEndColor = 590,
    kAliasWebkitBorderEndStyle = 591,
    kAliasWebkitBorderEndWidth = 592,
    kAliasWebkitBorderStartColor = 593,
    kAliasWebkitBorderStartStyle = 594,
    kAliasWebkitBorderStartWidth = 595,
    kAliasWebkitBorderBeforeColor = 576,
    kAliasWebkitBorderBeforeStyle = 577,
    kAliasWebkitBorderBeforeWidth = 578,
    kAliasWebkitBorderAfterColor = 573,
    kAliasWebkitBorderAfterStyle = 574,
    kAliasWebkitBorderAfterWidth = 575,
    kAliasWebkitMarginEnd = 711,
    kAliasWebkitMarginStart = 712,
    kAliasWebkitMarginBefore = 709,
    kAliasWebkitMarginAfter = 708,
    kAliasWebkitPaddingEnd = 761,
    kAliasWebkitPaddingStart = 762,
    kAliasWebkitPaddingBefore = 759,
    kAliasWebkitPaddingAfter = 758,
    kAliasWebkitLogicalWidth = 672,
    kAliasWebkitLogicalHeight = 572,
    kAliasWebkitMinLogicalWidth = 729,
    kAliasWebkitMinLogicalHeight = 727,
    kAliasWebkitMaxLogicalWidth = 724,
    kAliasWebkitMaxLogicalHeight = 722,
    kAliasWebkitBorderAfter = 924,
    kAliasWebkitBorderBefore = 925,
    kAliasWebkitBorderEnd = 933,
    kAliasWebkitBorderStart = 934,
    kAliasEpubCaptionSide = 614,
    kAliasEpubTextCombine = 894,
    kAliasEpubTextEmphasis = 996,
    kAliasEpubTextEmphasisColor = 896,
    kAliasEpubTextEmphasisStyle = 898,
    kAliasEpubTextOrientation = 549,
    kAliasEpubTextTransform = 835,
    kAliasEpubWordBreak = 912,
    kAliasEpubWritingMode = 550,
    kAliasWebkitAlignContent = 553,
    kAliasWebkitAlignItems = 554,
    kAliasWebkitAlignSelf = 555,
    kAliasWebkitAnimation = 917,
    kAliasWebkitAnimationDelay = 514,
    kAliasWebkitAnimationDirection = 515,
    kAliasWebkitAnimationDuration = 516,
    kAliasWebkitAnimationFillMode = 517,
    kAliasWebkitAnimationIterationCount = 518,
    kAliasWebkitAnimationName = 519,
    kAliasWebkitAnimationPlayState = 520,
    kAliasWebkitAnimationTimingFunction = 521,
    kAliasWebkitBackfaceVisibility = 559,
    kAliasWebkitBackgroundClip = 562,
    kAliasWebkitBackgroundOrigin = 565,
    kAliasWebkitBackgroundSize = 570,
    kAliasWebkitBorderBottomLeftRadius = 580,
    kAliasWebkitBorderBottomRightRadius = 581,
    kAliasWebkitBorderRadius = 938,
    kAliasWebkitBorderTopLeftRadius = 603,
    kAliasWebkitBorderTopRightRadius = 604,
    kAliasWebkitBoxShadow = 608,
    kAliasWebkitBoxSizing = 609,
    kAliasWebkitClipPath = 618,
    kAliasWebkitColumnCount = 623,
    kAliasWebkitColumnGap = 625,
    kAliasWebkitColumnRule = 944,
    kAliasWebkitColumnRuleColor = 626,
    kAliasWebkitColumnRuleStyle = 627,
    kAliasWebkitColumnRuleWidth = 628,
    kAliasWebkitColumnSpan = 629,
    kAliasWebkitColumnWidth = 630,
    kAliasWebkitColumns = 945,
    kAliasWebkitFilter = 646,
    kAliasWebkitFlex = 946,
    kAliasWebkitFlexBasis = 647,
    kAliasWebkitFlexDirection = 648,
    kAliasWebkitFlexFlow = 947,
    kAliasWebkitFlexGrow = 649,
    kAliasWebkitFlexShrink = 650,
    kAliasWebkitFlexWrap = 651,
    kAliasWebkitFontFeatureSettings = 530,
    kAliasWebkitJustifyContent = 696,
    kAliasWebkitOpacity = 740,
    kAliasWebkitOrder = 741,
    kAliasWebkitPerspective = 768,
    kAliasWebkitPerspectiveOrigin = 769,
    kAliasWebkitShapeImageThreshold = 802,
    kAliasWebkitShapeMargin = 803,
    kAliasWebkitShapeOutside = 804,
    kAliasWebkitTextSizeAdjust = 834,
    kAliasWebkitTransform = 839,
    kAliasWebkitTransformOrigin = 841,
    kAliasWebkitTransformStyle = 842,
    kAliasWebkitTransition = 987,
    kAliasWebkitTransitionDelay = 522,
    kAliasWebkitTransitionDuration = 523,
    kAliasWebkitTransitionProperty = 524,
    kAliasWebkitTransitionTimingFunction = 525,
    kAliasWebkitUserSelect = 846,
    kAliasWordWrap = 751,
};

const CSSPropertyID kCSSPropertyAliasList[] = {
    CSSPropertyID::kAliasWebkitBorderEndColor,
    CSSPropertyID::kAliasWebkitBorderEndStyle,
    CSSPropertyID::kAliasWebkitBorderEndWidth,
    CSSPropertyID::kAliasWebkitBorderStartColor,
    CSSPropertyID::kAliasWebkitBorderStartStyle,
    CSSPropertyID::kAliasWebkitBorderStartWidth,
    CSSPropertyID::kAliasWebkitBorderBeforeColor,
    CSSPropertyID::kAliasWebkitBorderBeforeStyle,
    CSSPropertyID::kAliasWebkitBorderBeforeWidth,
    CSSPropertyID::kAliasWebkitBorderAfterColor,
    CSSPropertyID::kAliasWebkitBorderAfterStyle,
    CSSPropertyID::kAliasWebkitBorderAfterWidth,
    CSSPropertyID::kAliasWebkitMarginEnd,
    CSSPropertyID::kAliasWebkitMarginStart,
    CSSPropertyID::kAliasWebkitMarginBefore,
    CSSPropertyID::kAliasWebkitMarginAfter,
    CSSPropertyID::kAliasWebkitPaddingEnd,
    CSSPropertyID::kAliasWebkitPaddingStart,
    CSSPropertyID::kAliasWebkitPaddingBefore,
    CSSPropertyID::kAliasWebkitPaddingAfter,
    CSSPropertyID::kAliasWebkitLogicalWidth,
    CSSPropertyID::kAliasWebkitLogicalHeight,
    CSSPropertyID::kAliasWebkitMinLogicalWidth,
    CSSPropertyID::kAliasWebkitMinLogicalHeight,
    CSSPropertyID::kAliasWebkitMaxLogicalWidth,
    CSSPropertyID::kAliasWebkitMaxLogicalHeight,
    CSSPropertyID::kAliasWebkitBorderAfter,
    CSSPropertyID::kAliasWebkitBorderBefore,
    CSSPropertyID::kAliasWebkitBorderEnd,
    CSSPropertyID::kAliasWebkitBorderStart,
    CSSPropertyID::kAliasEpubCaptionSide,
    CSSPropertyID::kAliasEpubTextCombine,
    CSSPropertyID::kAliasEpubTextEmphasis,
    CSSPropertyID::kAliasEpubTextEmphasisColor,
    CSSPropertyID::kAliasEpubTextEmphasisStyle,
    CSSPropertyID::kAliasEpubTextOrientation,
    CSSPropertyID::kAliasEpubTextTransform,
    CSSPropertyID::kAliasEpubWordBreak,
    CSSPropertyID::kAliasEpubWritingMode,
    CSSPropertyID::kAliasWebkitAlignContent,
    CSSPropertyID::kAliasWebkitAlignItems,
    CSSPropertyID::kAliasWebkitAlignSelf,
    CSSPropertyID::kAliasWebkitAnimation,
    CSSPropertyID::kAliasWebkitAnimationDelay,
    CSSPropertyID::kAliasWebkitAnimationDirection,
    CSSPropertyID::kAliasWebkitAnimationDuration,
    CSSPropertyID::kAliasWebkitAnimationFillMode,
    CSSPropertyID::kAliasWebkitAnimationIterationCount,
    CSSPropertyID::kAliasWebkitAnimationName,
    CSSPropertyID::kAliasWebkitAnimationPlayState,
    CSSPropertyID::kAliasWebkitAnimationTimingFunction,
    CSSPropertyID::kAliasWebkitBackfaceVisibility,
    CSSPropertyID::kAliasWebkitBackgroundClip,
    CSSPropertyID::kAliasWebkitBackgroundOrigin,
    CSSPropertyID::kAliasWebkitBackgroundSize,
    CSSPropertyID::kAliasWebkitBorderBottomLeftRadius,
    CSSPropertyID::kAliasWebkitBorderBottomRightRadius,
    CSSPropertyID::kAliasWebkitBorderRadius,
    CSSPropertyID::kAliasWebkitBorderTopLeftRadius,
    CSSPropertyID::kAliasWebkitBorderTopRightRadius,
    CSSPropertyID::kAliasWebkitBoxShadow,
    CSSPropertyID::kAliasWebkitBoxSizing,
    CSSPropertyID::kAliasWebkitClipPath,
    CSSPropertyID::kAliasWebkitColumnCount,
    CSSPropertyID::kAliasWebkitColumnGap,
    CSSPropertyID::kAliasWebkitColumnRule,
    CSSPropertyID::kAliasWebkitColumnRuleColor,
    CSSPropertyID::kAliasWebkitColumnRuleStyle,
    CSSPropertyID::kAliasWebkitColumnRuleWidth,
    CSSPropertyID::kAliasWebkitColumnSpan,
    CSSPropertyID::kAliasWebkitColumnWidth,
    CSSPropertyID::kAliasWebkitColumns,
    CSSPropertyID::kAliasWebkitFilter,
    CSSPropertyID::kAliasWebkitFlex,
    CSSPropertyID::kAliasWebkitFlexBasis,
    CSSPropertyID::kAliasWebkitFlexDirection,
    CSSPropertyID::kAliasWebkitFlexFlow,
    CSSPropertyID::kAliasWebkitFlexGrow,
    CSSPropertyID::kAliasWebkitFlexShrink,
    CSSPropertyID::kAliasWebkitFlexWrap,
    CSSPropertyID::kAliasWebkitFontFeatureSettings,
    CSSPropertyID::kAliasWebkitJustifyContent,
    CSSPropertyID::kAliasWebkitOpacity,
    CSSPropertyID::kAliasWebkitOrder,
    CSSPropertyID::kAliasWebkitPerspective,
    CSSPropertyID::kAliasWebkitPerspectiveOrigin,
    CSSPropertyID::kAliasWebkitShapeImageThreshold,
    CSSPropertyID::kAliasWebkitShapeMargin,
    CSSPropertyID::kAliasWebkitShapeOutside,
    CSSPropertyID::kAliasWebkitTextSizeAdjust,
    CSSPropertyID::kAliasWebkitTransform,
    CSSPropertyID::kAliasWebkitTransformOrigin,
    CSSPropertyID::kAliasWebkitTransformStyle,
    CSSPropertyID::kAliasWebkitTransition,
    CSSPropertyID::kAliasWebkitTransitionDelay,
    CSSPropertyID::kAliasWebkitTransitionDuration,
    CSSPropertyID::kAliasWebkitTransitionProperty,
    CSSPropertyID::kAliasWebkitTransitionTimingFunction,
    CSSPropertyID::kAliasWebkitUserSelect,
    CSSPropertyID::kAliasWordWrap,
};

const int kIntFirstCSSProperty = 2;
const CSSPropertyID firstCSSProperty = static_cast<CSSPropertyID>(kIntFirstCSSProperty);
const int numCSSProperties = 584;
const int kIntLastCSSProperty = 485;
const CSSPropertyID lastCSSProperty = static_cast<CSSPropertyID>(kIntLastCSSProperty);
const CSSPropertyID lastUnresolvedCSSProperty = static_cast<CSSPropertyID>(996);
const int numCSSPropertyIDs = static_cast<int>(lastUnresolvedCSSProperty) + 1;
const size_t maxCSSPropertyNameLength = 48;

inline int GetCSSPropertyIDIndex(CSSPropertyID id) {
    DCHECK_GE(id, firstCSSProperty);
    DCHECK_LE(id, lastCSSProperty);
    return static_cast<int>(id) - kIntFirstCSSProperty;
}

inline bool isCSSPropertyIDWithName(CSSPropertyID id)
{
    return id >= firstCSSProperty && id <= lastUnresolvedCSSProperty;
}

inline bool isValidCSSPropertyID(CSSPropertyID id)
{
    return id != CSSPropertyID::kInvalid;
}

inline CSSPropertyID convertToCSSPropertyID(int value)
{
    DCHECK_GE(value, static_cast<int>(CSSPropertyID::kInvalid));
    DCHECK_LE(value, kIntLastCSSProperty);
    return static_cast<CSSPropertyID>(value);
}

inline CSSPropertyID resolveCSSPropertyID(CSSPropertyID id)
{
    return convertToCSSPropertyID(static_cast<int>(id) & ~512);
}

inline bool isPropertyAlias(CSSPropertyID id) { return static_cast<int>(id) & 512; }

CSSPropertyID CORE_EXPORT unresolvedCSSPropertyID(const WTF::String&);

CSSPropertyID CORE_EXPORT cssPropertyID(const WTF::String&);

class CSSPropertyIDList {
  STACK_ALLOCATED();
 public:
    class Iterator {
      STACK_ALLOCATED();
     public:
      Iterator(int id) : id_(id) {}
      CSSPropertyID operator*() const { return convertToCSSPropertyID(id_); }
      Iterator& operator++() { id_++; return *this; }
      bool operator!=(const Iterator& i) const { return id_ != i.id_; }
     private:
      int id_;
    };
  Iterator begin() const { return Iterator(kIntFirstCSSProperty); }
  Iterator end() const { return Iterator(kIntLastCSSProperty + 1); }
};

mojom::blink::CSSSampleId CORE_EXPORT GetCSSSampleId(CSSPropertyID id);

}  // namespace blink

#endif  // THIRD_PARTY_BLINK_RENDERER_CORE_CSS_CSS_PROPERTY_NAMES_H_
